@@ -23,6 +23,12 @@ use tui::{
     Frame, Terminal,
 };
 
+const ACTIVE_COLOR: Color = Color::Cyan;
+const DONE_COLOR: Color = Color::Green;
+const WARNING_COLOR: Color = Color::Yellow;
+const DANGER_COLOR: Color = Color::Red;
+const PASSIVE_COLOR: Color = Color::Gray;
+
 /// A basic example
 #[derive(StructOpt, Debug)]
 #[structopt(name = "basic")]
@@ -107,12 +113,12 @@ impl App {
         match self.time_goal {
             Some(i) => {
                 if duration as i64 >= i {
-                    Color::Green
+                    DONE_COLOR
                 } else {
-                    Color::Blue
+                    ACTIVE_COLOR
                 }
             }
-            None => Color::DarkGray,
+            None => PASSIVE_COLOR,
         }
     }
 
@@ -121,12 +127,12 @@ impl App {
         match self.word_goal {
             Some(i) => {
                 if word_count as i64 >= i {
-                    Color::Green
+                    DONE_COLOR
                 } else {
-                    Color::Yellow
+                    WARNING_COLOR
                 }
             }
-            None => Color::DarkGray,
+            None => PASSIVE_COLOR,
         }
     }
 
@@ -142,15 +148,18 @@ impl App {
         word_goal_achieved && time_goal_achieved
     }
 
-    fn get_title(&self) -> Vec<Span> {
+    fn get_instruction(&self) -> Vec<Span> {
         match self.input_mode {
             InputMode::Title => {
                 let save_and = if self.has_text() { " save and" } else { "" };
                 vec![
                     Span::raw("Press "),
-                    Span::styled("Esc", Style::default().add_modifier(Modifier::BOLD)),
+                    Span::styled("[Esc]", Style::default().add_modifier(Modifier::BOLD)),
                     Span::raw(format!(" to{save_and} exit. ")),
-                    Span::styled("Enter", Style::default().add_modifier(Modifier::BOLD)),
+                    Span::styled(
+                        "Press [Enter]",
+                        Style::default().add_modifier(Modifier::BOLD),
+                    ),
                     Span::raw(" to start the writing session."),
                 ]
             }
@@ -162,7 +171,7 @@ impl App {
                 } else {
                     vec![
                         Span::raw("Press "),
-                        Span::styled("Esc", Style::default().add_modifier(Modifier::BOLD)),
+                        Span::styled("[Esc]", Style::default().add_modifier(Modifier::BOLD)),
                         Span::raw(" to stop writing"),
                     ]
                 }
@@ -172,18 +181,18 @@ impl App {
 
     fn get_widget_colors(&self) -> (Color, Color) {
         match self.input_mode {
-            InputMode::Title => (Color::Blue, Color::DarkGray),
+            InputMode::Title => (ACTIVE_COLOR, PASSIVE_COLOR),
             InputMode::Writing => match (self.keystroke_timeout, self.last_keystroke) {
                 (Some(timeout), Some(last_keystroke)) => {
                     if last_keystroke.elapsed().as_secs_f32() > 0.8 * timeout as f32 {
-                        (Color::DarkGray, Color::Red)
+                        (PASSIVE_COLOR, DANGER_COLOR)
                     } else if last_keystroke.elapsed().as_secs_f32() > 0.5 * timeout as f32 {
-                        (Color::DarkGray, Color::Yellow)
+                        (PASSIVE_COLOR, WARNING_COLOR)
                     } else {
-                        (Color::DarkGray, Color::Blue)
+                        (PASSIVE_COLOR, ACTIVE_COLOR)
                     }
                 }
-                _ => (Color::DarkGray, Color::Blue),
+                _ => (PASSIVE_COLOR, ACTIVE_COLOR),
             },
         }
     }
@@ -197,7 +206,7 @@ impl App {
 
         let total_lines = wrapped_text.lines().count();
         let mut final_text = String::default();
-        let skip = if total_lines > paragraph_rows - 1 {
+        let skip = if total_lines > max(1, paragraph_rows) - 1 {
             total_lines - paragraph_rows + 1
         } else {
             0
@@ -235,6 +244,21 @@ fn get_text_position(text: &str) -> (u16, u16) {
     )
 }
 
+fn create_default_config() -> bool {
+    if let Some(config_dir) = dirs::config_dir() {
+        let config_directory = config_dir.join("writingbuddy/");
+        if std::fs::create_dir_all(&config_directory).is_ok() {
+            let config_file = config_directory.join("config.toml");
+            let config_contents = include_str!("../default_config.toml");
+            println!("Writing default config to: {:?}", config_file);
+            if std::fs::write(config_file, config_contents).is_ok() {
+                return true;
+            }
+        }
+    }
+    false
+}
+
 fn main() -> Result<(), Box<dyn Error>> {
     let cli_config = CliConfig::from_args();
 
@@ -247,7 +271,34 @@ fn main() -> Result<(), Box<dyn Error>> {
             std::process::exit(1);
         }
     } else if settings.merge(config::File::with_name("config")).is_err() {
-        println!("No config file found. Using default values");
+        println!("No config file in current directory found.");
+        if let Some(config_dir) = dirs::config_dir() {
+            let config_file = config_dir
+                .join("writingbuddy/config")
+                .to_str()
+                .unwrap()
+                .to_string();
+            settings = Config::default();
+            if settings
+                .merge(config::File::with_name(&config_file))
+                .is_err()
+            {
+                println!(
+                    "Failed loading config file {:?}! Creating a default config.",
+                    config_file
+                );
+                if create_default_config() {
+                    settings = Config::default();
+                    if settings
+                        .merge(config::File::with_name(&config_file))
+                        .is_err()
+                    {
+                        println!("Failed to read default config that should exist. Exit now");
+                        std::process::exit(1);
+                    }
+                }
+            }
+        }
     }
 
     let now = Utc::now();
@@ -304,7 +355,9 @@ fn main() -> Result<(), Box<dyn Error>> {
             .create(true)
             .open(&filename.to_string())
             .unwrap();
-        writeln!(output, "{}", app.title)?;
+        if !app.title.is_empty() {
+            writeln!(output, "{}", app.title)?;
+        }
         writeln!(output, "{}", app.text)?;
         writeln!(output)?;
     }
@@ -383,7 +436,7 @@ fn ui<B: Backend>(f: &mut Frame<B>, app: &App) {
         .margin(2)
         .constraints(
             [
-                Constraint::Length(1),
+                Constraint::Length(3),
                 Constraint::Length(3),
                 Constraint::Min(1),
                 Constraint::Length(3),
@@ -392,8 +445,10 @@ fn ui<B: Backend>(f: &mut Frame<B>, app: &App) {
         )
         .split(f.size());
 
-    let text = Text::from(Spans::from(app.get_title()));
-    let help_message = Paragraph::new(text);
+    let text = Text::from(Spans::from(app.get_instruction()));
+    let help_message = Paragraph::new(text)
+        .style(Style::default().fg(PASSIVE_COLOR))
+        .block(Block::default().borders(Borders::ALL).title("Instructions"));
     f.render_widget(help_message, chunks[0]);
 
     let widget_colors = app.get_widget_colors();
@@ -403,8 +458,8 @@ fn ui<B: Backend>(f: &mut Frame<B>, app: &App) {
         .block(Block::default().borders(Borders::ALL).title("Title"));
     f.render_widget(title, chunks[1]);
 
-    let paragraph_cols = f.size().width as usize - 6; // subtract 6 for border
-    let paragraph_rows = chunks[2].height as usize - 2; // subtract 2 for border
+    let paragraph_cols = max(6, f.size().width as usize) - 6; // subtract 6 for border
+    let paragraph_rows = max(2, chunks[2].height as usize) - 2; // subtract 2 for border
 
     let wrapped_text = app.get_paragraph_text(paragraph_rows, paragraph_cols);
 
